@@ -23,8 +23,8 @@ RcppExport SEXP MLEdMaxLLdx(SEXP arg1, SEXP arg2, SEXP arg3, SEXP arg4);
 // abremPivotals code
 RcppExport SEXP LSLR(SEXP arg1, SEXP arg2, SEXP arg3, SEXP arg4);
 RcppExport SEXP pivotalMC(SEXP arg1, SEXP arg2, SEXP arg3, SEXP arg4, SEXP arg5, SEXP arg6,SEXP arg7,SEXP arg8);
-RcppExport SEXP CallgetCCC2(SEXP arg1, SEXP model);
-RcppExport SEXP CallgetPvalue(SEXP arg1, SEXP arg2, SEXP arg3);
+//RcppExport SEXP CallgetCCC2(SEXP arg1, SEXP model);
+//RcppExport SEXP CallgetPvalue(SEXP arg1, SEXP arg2, SEXP arg3);
 
 //extern "C" double getCCC2( int F, int model);
 //extern "C" struct AbPval getPvalue(int F, double R2, int model);
